import { Module } from '@nestjs/common';
import { MailerModule } from '@nestjs-modules/mailer';
import { HandlebarsAdapter } from '@nestjs-modules/mailer/dist/adapters/handlebars.adapter';
import { ConfigModule } from '@nestjs/config';
import { JwtModule } from '@nestjs/jwt';
import { ServeStaticModule } from '@nestjs/serve-static';
import { TypeOrmModule } from '@nestjs/typeorm';
import { join } from 'path';
import { AppController } from './app.controller';
import { AppService } from './app.service';
import JwtConfigService from './core/jwt/jwt-config.service';
import { DoSpacesServicerovider } from './modules/SpacesModule/SpacesService';
import { DoSpacesService } from './modules/SpacesModule/SpacesService/doSpacesService';
import { SpacesModule } from './modules/SpacesModule/spaces.module';
import { AuthModule } from './modules/auth/auth.module';
import { EmailNotifierRepository } from './modules/email-notifier/email-notifier-repository';
import { EmailNotifierModule } from './modules/email-notifier/email-notifier.module';
import { FileUploadsModule } from './modules/file-uploads/file-uploads.module';
import { FileUploadsService } from './modules/file-uploads/file-uploads.service';
import { MailSenderModule } from './modules/mail-sender/mail-sender.module';
import { MailSenderService } from './modules/mail-sender/mail-sender.service';
import { SendEmailRepository } from './modules/send-email/send-email-repository';
import { SendEmailModule } from './modules/send-email/send-email.module';
import { SendEmailService } from './modules/send-email/send-email.service';
import { UsersRepository } from './modules/users/user.repository';
import { UsersModule } from './modules/users/users.module';
import { UsersService } from './modules/users/users.service';
import { AboutPageSectionOneCmsModule } from './modules/CMS/about-page-section-one-cms/about-page-section-one-cms.module';
import { AboutPageOurMissionSectionCmsModule } from './modules/CMS/about-page-our-mission-section-cms/about-page-our-mission-section-cms.module';
import { AboutPageOurCommunitySectionCmsModule } from './modules/CMS/about-page-our-community-section-cms/about-page-our-community-section-cms.module';
import { AboutPageOpenSourceCommunitySectionCmsModule } from './modules/CMS/about-page-open-source-community-section-cms/about-page-open-source-community-section-cms.module';
import { AboutPageSectionTwoCmsModule } from './modules/CMS/about-page-section-two-cms/about-page-section-two-cms.module';
import { SiteFrontendModule } from './modules/site-frontend/site-frontend.module';
import { ContactPageCmsModule } from './modules/CMS/contact-page-cms/contact-page-cms.module';
import { ContactModelModule } from './modules/CRUD/contact-model/contact-model.module';
import { FAQModule } from './modules/CRUD/faq/faq.module';
import { FaqPageCmsModule } from './modules/CMS/faq-page-cms/faq-page-cms.module';
import { BrandModule } from './modules/product/brand/brand.module';
import { LoginPageCmsModule } from './modules/CMS/login-page-cms/login-page-cms.module';
import { RegistrationPageCmsModule } from './modules/CMS/registration-page-cms/registration-page-cms.module';
import { ResetPasswordPageCmsModule } from './modules/CMS/reset-password-page-cms/reset-password-page-cms.module';
import { TermsAndConditionPageCmsModule } from './modules/CMS/terms-and-condition-page-cms/terms-and-condition-page-cms.module';
import { PrivacyPolicyPageCmsModule } from './modules/CMS/privacy-page-cms/privacy-policy-page-cms.module';
import { SocialLinksModule } from './modules/CRUD/social-links/social-links.module';
import { FooterBannerCmsModule } from './modules/CMS/footer-banner-cms/footer-banner-cms.module';
import { RefundPolicyCmsModule } from './modules/CMS/refund-policy-cms/refund-policy-cms.module';
import { HeaderFooterCmsModule } from './modules/CMS/header-footer-cms/header-footer-cms.module';
import { HomePageAboutSectionCmsModule } from './modules/CMS/home-page-about-section-cms/home-page-about-section-cms.module';
import { BlogPostModule } from './modules/blog-post/blog-post.module';
import { HomePageDiscoverSectionCmsModule } from './modules/CMS/home-page-discover-section-cms/home-page-discover-section-cms.module';
import { HomePageOurProductsSectionCmsModule } from './modules/CMS/home-page-our-products-section-cms/home-page-our-products-section-cms.module';
import { HomePageHeroSectionModule } from './modules/CRUD/home-page-hero-section/home-page-hero-section.module';
import { HomePageBannerSectionCmsModule } from './modules/CMS/home-page-banner-section-cms/home-page-banner-section-cms.module';
import { HomePagePackageSectionCmsModule } from './modules/CMS/home-page-package-section-cms/home-page-package-section-cms.module';
import { HomePageBlogSectionCmsModule } from './modules/CMS/home-page-blog-section-cms/home-page-blog-section-cms.module';
import { HomePageInstagramSectionCmsModule } from './modules/CMS/home-page-instagram-section-cms/home-page-instagram-section-cms.module';
import { HomePageTestimonialSectionCmsModule } from './modules/CMS/home-page-testimonial-section-cms/home-page-testimonial-section-cms.module';
import { PurchaseAndDeliveryPolicyModule } from './modules/CRUD/purchase-and-delivery-policy/purchase-and-delivery-policy.module';
import { HomePagePromotionSectionModule } from './modules/CRUD/home-page-promotion-section/home-page-promotion-section.module';
import { ProductOffersModule } from './modules/product/product-offers/product-offers.module';
import { HomePageAboutSectionModule } from './modules/CRUD/home-page-about-section/home-page-about-section.module';
import { TestimonialsModule } from './modules/CRUD/testimonials/testimonials.module';
import { InstagramServiceModule } from './modules/CRUD/instagram-service/instagram-service.module';
import { PurchaseAndDeliveryPolicyCmsModule } from './modules/CMS/purchase-and-delivery-policy-cms/purchase-and-delivery-policy-cms.module';
import { ColorsModule } from './modules/product/color/color.module';
import { ShippingMethodCMSModule } from './modules/CMS/shipping-method-cms/shipping-method-cms.module';
import { UpsConfigurationModule } from './modules/ups-configuration/ups-configuration.module';
import { SalesTaxCMSModule } from './modules/CMS/sales-tax-cms/sales-tax-cms.module';
import { ShippingAddressModule } from './modules/address/shipping-address/shipping-address.module';
import { BillingAddressModule } from './modules/address/billing-address/billing-address.module';
import { ProductModule } from './modules/product/product/product.module';
import { OrderModule } from "./modules/orders/order/orders.module";
import { OrderDetailsModule } from "./modules/orders/order-details/order-details.module";
import { PaymentConfigurationModule } from "./modules/payment-configuration/payment-configuration.module";
import { RefundItemModule } from "./modules/refund-item/refund-item.module";
import { PaymentGatewayModule } from "./modules/payment-gateway/payment-gateway.module";
import { UpsCoreModule } from "./modules/ups/ups-core/ups-core.module";
import { UpsShippingModule } from "./modules/ups/ups-shipping/ups-shipping.module";
import { ProductReviewModule } from './modules/product/product-review/product-review.module';
import { CouponModule } from './modules/orders/coupon/coupon.module';
import { ReturnProductsModule } from "./modules/return-products/return-products.module";
import { NewsletterModule } from './modules/CRUD/newsletter/newsletter.module';
import { DashboardModule } from './modules/dashboard/dashboard.module';
import { PackagesModule } from './modules/CRUD/packages/packages.module';

@Module({
    imports: [
        ServeStaticModule.forRoot({
            rootPath: join(__dirname, '..', 'uploads')
        }),
        ConfigModule.forRoot({ isGlobal: true }),
        TypeOrmModule.forRoot({
            type: 'mysql',
            host: process.env.HOST,
            port: parseInt(process.env.PORT),
            username: process.env.USERNAME,
            // username: 'root',
            password: process.env.PASSWORD,
            database: process.env.DATABASE,
            autoLoadEntities: true,
            synchronize: true,
            dropSchema: false
        }),
        TypeOrmModule.forFeature([UsersRepository]),
        TypeOrmModule.forFeature([SendEmailRepository]),
        TypeOrmModule.forFeature([EmailNotifierRepository]),
        JwtModule.registerAsync({
            useClass: JwtConfigService
        }),
        MailerModule.forRoot({
            transport: {
                host: process.env.EMAIL_HOST,
                port: parseInt(process.env.EMAIL_PORT),
                secure: true,
                auth: {
                    user: process.env.EMAIL_USER,
                    pass: process.env.EMAIL_PASS
                }
            },
            defaults: {
                from: `"${process.env.EMAIL_SENDER_NAME}" <${process.env.EMAIL_SENDER_MAIL}>`
            },
            template: {
                dir: __dirname + '/templates/**/*',
                adapter: new HandlebarsAdapter(),
                options: {
                    strict: true
                }
            }
        }),
        UsersModule,
        AuthModule,
        EmailNotifierModule,
        FileUploadsModule,
        SendEmailModule,
        MailSenderModule,
        SpacesModule,
        AboutPageSectionOneCmsModule,
        AboutPageOurMissionSectionCmsModule,
        AboutPageOurCommunitySectionCmsModule,
        AboutPageOpenSourceCommunitySectionCmsModule,
        AboutPageSectionTwoCmsModule,
        SiteFrontendModule,
        ContactPageCmsModule,
        ContactModelModule,
        FAQModule,
        FaqPageCmsModule,
        BrandModule,
        LoginPageCmsModule,
        RegistrationPageCmsModule,
        ResetPasswordPageCmsModule,
        TermsAndConditionPageCmsModule,
        PrivacyPolicyPageCmsModule,
        SocialLinksModule,
        FooterBannerCmsModule,
        RefundPolicyCmsModule,
        HeaderFooterCmsModule,
        HomePageAboutSectionCmsModule,
        BlogPostModule,
        HomePageDiscoverSectionCmsModule,
        HomePageOurProductsSectionCmsModule,
        HomePageHeroSectionModule,
        HomePageBannerSectionCmsModule,
        HomePagePackageSectionCmsModule,
        HomePageBlogSectionCmsModule,
        HomePageInstagramSectionCmsModule,
        HomePageTestimonialSectionCmsModule,
        PurchaseAndDeliveryPolicyModule,
        HomePagePromotionSectionModule,
        ProductOffersModule,
        HomePageAboutSectionModule,
        TestimonialsModule,
        InstagramServiceModule,
        PurchaseAndDeliveryPolicyCmsModule,
        ColorsModule,
        ShippingMethodCMSModule,
        UpsConfigurationModule,
        SalesTaxCMSModule,
        ShippingAddressModule,
        BillingAddressModule,
        ProductModule,
        ProductReviewModule,
        OrderModule,
        OrderDetailsModule,
        PaymentConfigurationModule,
        RefundItemModule,
        PaymentGatewayModule,
        UpsShippingModule,
        UpsCoreModule,
        CouponModule,
        ReturnProductsModule,
        NewsletterModule,
        DashboardModule,
        PackagesModule,
    ],
    controllers: [AppController],
    providers: [
        AppService,
        UsersService,
        SendEmailService,
        FileUploadsService,
        DoSpacesService,
        DoSpacesServicerovider,
        MailSenderService
    ]
})
export class AppModule {}
