import {
    Body,
    Controller,
    Get,
    HttpCode,
    HttpStatus,
    Post,
    UploadedFiles,
    UseGuards,
    UseInterceptors
} from "@nestjs/common";
import { AdminAuthGuard } from "src/core/guards/admin-auth.guard";
import { Constants } from "src/utils/constants";
import { FileFieldsInterceptor } from "@nestjs/platform-express";
import { UploadedMulterFileI } from "src/modules/SpacesModule/SpacesService";
import { AboutPageSectionOneCmsService } from "./about-page-section-one-cms.service";
import { UpdateAboutPageSectionOneCmsDto } from "./dto/update-about-page-section-one-cms.dto";

@Controller({ path: "about-page-section-one-cms", version: Constants.API_VERSION_1 })

export class AboutPageSectionOneCmsController {
    constructor(private readonly service: AboutPageSectionOneCmsService) { }

    @Post()
    @HttpCode(HttpStatus.OK)
    @UseGuards(AdminAuthGuard)
    @UseInterceptors(FileFieldsInterceptor(
        [
            { name: "imageOne", maxCount: 1 },
            { name: "imageTwo", maxCount: 1 }
        ]
    ))
    updateOrCreateData(
        @Body() dto: UpdateAboutPageSectionOneCmsDto,
        @UploadedFiles() files: {
            imageOne: UploadedMulterFileI,
            imageTwo: UploadedMulterFileI
        }
    ) {
        return this.service.updateOrCreateData(dto, files);
    }

    @Get()
    @UseGuards(AdminAuthGuard)
    findAll() {
        return this.service.findAll();
    }
}
