import { EntityRepository, getConnection, Repository } from "typeorm";
import { PackagesEntity } from "./entities/packages.entity";
import { CreatePackagesDto } from "./dto/create-packages.dto";
import { UpdatePackagesDto } from "./dto/update-packages.dto";

@EntityRepository(PackagesEntity)
export class PackagesRepository extends Repository<PackagesEntity> {
    async createEntity(dto: CreatePackagesDto): Promise<PackagesEntity | Error> {
        try {
            const {
                productId,
                productName,
                productUrlSlug,
                packageDetails,
            } = dto;
            const entity = this.create({
                productId,
                productName,
                productUrlSlug,
                packageDetails
            });
            await this.save(entity);
            return entity;
        } catch (e) {
            return e;
        }
    }

    async findOneEntity(id: string): Promise<PackagesEntity | Error> {
        try {
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async updateEntity(id: string, dto: UpdatePackagesDto): Promise<PackagesEntity | Error> {
        try {
            await this.update(id, {
                productId: dto.productId,
                productName: dto.productName,
                productUrlSlug: dto.productUrlSlug,
                packageDetails: dto.packageDetails
            });
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async findByFilterQuery(query: any): Promise<PackagesEntity[] | Error> {
        try {
            return await this.find({
                where: { ...query, isDeleted: false }
            });
        } catch (e) {
            return e;
        }
    }

    async deleteEntity(id: string): Promise<boolean | Error> {
        try {
            const updateResult = await getConnection()
                .createQueryBuilder()
                .update(PackagesEntity)
                .set({ isDeleted: true })
                .where("id = :id", { id: id })
                .execute();
            if (updateResult.affected > 0) {
                return true;
            }
            return false;
        } catch (e) {
            return e;
        }
    }
}