import { EntityRepository, getConnection, Repository } from "typeorm";
import { PurchaseAndDeliveryPolicy } from "./entities/purchase-and-delivery-policy.entity";
import { CreatePurchaseAndDeliveryPolicyDto } from "./dto/create-purchase-and-delivery-policy.dto";
import { UpdatePurchaseAndDeliveryPolicyDto } from "./dto/update-purchase-and-delivery-policy.dto";

@EntityRepository(PurchaseAndDeliveryPolicy)
export class PurchaseAndDeliveryPolicyRepository extends Repository<PurchaseAndDeliveryPolicy> {
    async createEntity(dto: CreatePurchaseAndDeliveryPolicyDto): Promise<PurchaseAndDeliveryPolicy | Error> {
        try {
            const {
                title,
                description
            } = dto;
            const entity = this.create({
                title,
                description
            });
            await this.save(entity);
            return entity;
        } catch (e) {
            return e;
        }
    }

    async findOneEntity(id: string): Promise<PurchaseAndDeliveryPolicy | Error> {
        try {
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async updateEntity(id: string, dto: UpdatePurchaseAndDeliveryPolicyDto): Promise<PurchaseAndDeliveryPolicy | Error> {
        try {
            await this.update(id, {
                title: dto.title,
                description: dto.description
            });
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async findByFilterQuery(query: any): Promise<PurchaseAndDeliveryPolicy[] | Error> {
        try {
            return await this.find({
                where: { ...query, isDeleted: false }
            });
        } catch (e) {
            return e;
        }
    }

    async deleteEntity(id: string): Promise<boolean | Error> {
        try {
            const updateResult = await getConnection()
                .createQueryBuilder()
                .update(PurchaseAndDeliveryPolicy)
                .set({ isDeleted: true })
                .where("id = :id", { id: id })
                .execute();
            if (updateResult.affected > 0) {
                return true;
            }
            return false;
        } catch (e) {
            return e;
        }
    }
}