import { HttpException, HttpStatus, Injectable } from "@nestjs/common";
import { InjectRepository } from "@nestjs/typeorm";
import { Constants } from "src/utils/constants";
import { ResponseUtils } from "src/utils/response.utils";
import { PurchaseAndDeliveryPolicyRepository } from "./purchase-and-delivery-policy.repository";
import { CreatePurchaseAndDeliveryPolicyDto } from "./dto/create-purchase-and-delivery-policy.dto";
import { PurchaseAndDeliveryPolicy } from "./entities/purchase-and-delivery-policy.entity";
import { UpdatePurchaseAndDeliveryPolicyDto } from "./dto/update-purchase-and-delivery-policy.dto";

@Injectable()
export class PurchaseAndDeliveryPolicyService {
    constructor(
        @InjectRepository(PurchaseAndDeliveryPolicyRepository)
        private readonly repository: PurchaseAndDeliveryPolicyRepository
    ) {
    }

    async create(dto: CreatePurchaseAndDeliveryPolicyDto): Promise<PurchaseAndDeliveryPolicy | Error> {
        const data = await this.repository.createEntity(dto);
        if (!data) {
            throw new HttpException(
                Constants.CREATE_FAILED,
                HttpStatus.BAD_REQUEST
            );
        }
        return ResponseUtils.successResponseHandler(201, "Data created successfully!", "data", data);
    }

    async update(id: string, dto: UpdatePurchaseAndDeliveryPolicyDto): Promise<PurchaseAndDeliveryPolicy | Error> {
        const res: any = await this.repository.findOneEntity(id);
        if (!res) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        const data = await this.repository.updateEntity(id, dto);
        if (!data) {
            throw new HttpException(
                Constants.UPDATE_FAILED,
                HttpStatus.BAD_REQUEST
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data updated successfully!", "data", data);
    }

    async findAll(): Promise<PurchaseAndDeliveryPolicy[] | Error> {
        const data = await this.repository.findByFilterQuery({});
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }

    async findOne(id: string): Promise<PurchaseAndDeliveryPolicy[] | Error> {
        const data = await this.repository.findByFilterQuery({ id: id });
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }

    async remove(id: string): Promise<boolean | Error> {
        const data = await this.repository.deleteEntity(id);
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.buildDeletedData(data, 200, "Data deleted successfully!");
    }
}
