import { Module } from '@nestjs/common';
import { JwtModule } from '@nestjs/jwt';
import { TypeOrmModule } from '@nestjs/typeorm';
import JwtConfigService from 'src/core/jwt/jwt-config.service';
import JwtHelper from 'src/core/jwt/jwt.helper';
import { UsersRepository } from '../users/user.repository';
import { SiteFrontendController } from './site-frontend.controller';
import { SiteFrontendService } from './site-frontend.service';
import { ChangePasswordTokenRepository } from '../change-password-token/change-password-token.repository';
import { EmailNotifierRepository } from '../email-notifier/email-notifier-repository';
import { AuthService } from '../auth/auth.service';
import { MailSenderService } from '../mail-sender/mail-sender.service';
import { AboutPageSectionOneCmsRepository } from '../CMS/about-page-section-one-cms/about-page-section-one-cms.repository';
import { AboutPageSectionTwoCmsRepository } from '../CMS/about-page-section-two-cms/about-page-section-two-cms.repository';
import { AboutPageOurMissionSectionCmsRepository } from '../CMS/about-page-our-mission-section-cms/about-page-our-mission-section-cms.repository';
import { AboutPageOurCommunitySectionCmsRepository } from '../CMS/about-page-our-community-section-cms/about-page-our-community-section-cms.repository';
import { AboutPageOpenSourceCommunitySectionCmsRepository } from '../CMS/about-page-open-source-community-section-cms/about-page-open-source-community-section-cms.repository';
import { FAQRepository } from '../CRUD/faq/faq.repository';
import { FaqPageCmsRepository } from '../CMS/faq-page-cms/faq-page-cms.repository';
import { ContactPageCmsRepository } from '../CMS/contact-page-cms/contact-page-cms.repository';
import { BlogPostRepository } from '../blog-post/blog-post.repository';
import { HomePageAboutSectionCmsRepository } from '../CMS/home-page-about-section-cms/home-page-about-section-cms.repository';
import { HomePageHeroSectionRepository } from '../CRUD/home-page-hero-section/home-page-hero-section.repository';
import { HomePageBannerSectionCmsRepository } from '../CMS/home-page-banner-section-cms/home-page-banner-section-cms.repository';
import { HomePageDiscoverSectionCmsRepository } from '../CMS/home-page-discover-section-cms/home-page-discover-section-cms.repository';
import { HomePageOurProductsSectionCmsRepository } from '../CMS/home-page-our-products-section-cms/home-page-our-products-section-cms.repository';
import { HeaderFooterCmsRepository } from '../CMS/header-footer-cms/header-footer-cms.repository';
import { FooterBannerCmsRepository } from '../CMS/footer-banner-cms/footer-banner-cms.repository';
import { SocialLinksRepository } from '../CRUD/social-links/social-links.repository';
import { HomePageBlogSectionCmsRepository } from '../CMS/home-page-blog-section-cms/home-page-blog-section-cms.repository';
import { HomePageInstagramSectionCmsRepository } from '../CMS/home-page-instagram-section-cms/home-page-instagram-section-cms.repository';
import { HomePagePackageSectionCmsRepository } from '../CMS/home-page-package-section-cms/home-page-package-section-cms.repository';
import { HomePageTestimonialSectionCmsRepository } from '../CMS/home-page-testimonial-section-cms/home-page-testimonial-section-cms.repository';
import { HomePagePromotionSectionRepository } from '../CRUD/home-page-promotion-section/home-page-promotion-section.repository';
import { HomePageAboutSectionRepository } from '../CRUD/home-page-about-section/home-page-about-section.repository';
import { TestimonialsRepository } from '../CRUD/testimonials/testimonials.repository';
import { InstagramServiceRepository } from '../CRUD/instagram-service/instagram-service.repository';
import { BillingAddressRepository } from '../address/billing-address/billing-address.repository';
import { ShippingAddressRepository } from '../address/shipping-address/shipping-address.repository';
import { ProductsRepository } from '../product/product/product.repository';
import { ProductColorVariantsRepository } from '../product/product-color-variants/product-color-variants.repository';
import { ProductOfferVariantsRepository } from '../product/product-offer-variants/product-offer-variants.repository';
import { ProductImageGalleryRepository } from '../product/product-image-gallery/product-image-gallery.repository';
import { ProductReviewRepository } from '../product/product-review/product-review.repository';
import { RefundPolicyCmsRepository } from '../CMS/refund-policy-cms/refund-policy-cms.repository';
import { PurchaseAndDeliveryPolicyCmsRepository } from '../CMS/purchase-and-delivery-policy-cms/purchase-and-delivery-policy-cms.repository';
import { PurchaseAndDeliveryPolicyRepository } from '../CRUD/purchase-and-delivery-policy/purchase-and-delivery-policy.repository';
import { SalesTaxCMSRepository } from '../CMS/sales-tax-cms/sales-tax-cms.repository';
import { CouponRepository } from '../orders/coupon/coupon.repository';
import { PackagesRepository } from '../CRUD/packages/packages.repository';

@Module({
    imports: [
        JwtModule.registerAsync({
            useClass: JwtConfigService
        }),
        TypeOrmModule.forFeature([
            UsersRepository,
            ChangePasswordTokenRepository,
            EmailNotifierRepository,
            AboutPageSectionOneCmsRepository,
            AboutPageSectionTwoCmsRepository,
            AboutPageOurMissionSectionCmsRepository,
            AboutPageOurCommunitySectionCmsRepository,
            AboutPageOpenSourceCommunitySectionCmsRepository,
            FAQRepository,
            FaqPageCmsRepository,
            ContactPageCmsRepository,
            BlogPostRepository,
            HomePageAboutSectionCmsRepository,
            HomePageHeroSectionRepository,
            HomePageBannerSectionCmsRepository,
            HomePageDiscoverSectionCmsRepository,
            HomePageOurProductsSectionCmsRepository,
            HeaderFooterCmsRepository,
            FooterBannerCmsRepository,
            SocialLinksRepository,
            HomePagePackageSectionCmsRepository,
            PackagesRepository,
            HomePageBlogSectionCmsRepository,
            HomePageTestimonialSectionCmsRepository,
            HomePageInstagramSectionCmsRepository,
            HomePageAboutSectionRepository,
            HomePagePromotionSectionRepository,
            TestimonialsRepository,
            InstagramServiceRepository,
            ShippingAddressRepository,
            BillingAddressRepository,
            ProductsRepository,
            ProductColorVariantsRepository,
            ProductOfferVariantsRepository,
            ProductImageGalleryRepository,
            ProductReviewRepository,
            RefundPolicyCmsRepository,
            PurchaseAndDeliveryPolicyCmsRepository,
            PurchaseAndDeliveryPolicyRepository,
            SalesTaxCMSRepository,
            CouponRepository
        ]),
    ],
    controllers: [SiteFrontendController],
    providers: [SiteFrontendService, AuthService, JwtHelper, MailSenderService]
})

export class SiteFrontendModule {}
